@@ -21,7 +21,6 @@ package config
 
 import (
 	"fmt"
-	"io/ioutil"
 	"os"
 	"os/exec"
 	"path/filepath"
@@ -76,6 +75,10 @@ var (
 	SysprepDisksDir = mountBaseDir + "/sysprep-disks"
 	// DownwardAPIDisksDir represents a path to DownwardAPI iso images
 	DownwardAPIDisksDir = mountBaseDir + "/downwardapi-disks"
+	// DownwardMetricDisksDir represents a path to DownwardMetric block disk
+	DownwardMetricDisksDir = mountBaseDir + "/downwardmetric-disk"
+	// DownwardMetricDisks represents the disk location for the DownwardMetric disk
+	DownwardMetricDisk = filepath.Join(DownwardAPIDisksDir, "vhostmd0")
 	// ServiceAccountDiskDir represents a path to the ServiceAccount iso image
 	ServiceAccountDiskDir = mountBaseDir + "/service-account-disk"
 	// ServiceAccountDiskName represents the name of the ServiceAccount iso image
@@ -97,7 +100,7 @@ func setEmptyIsoCreationFunction(emptyIsoFunc emptyIsoCreationFunc) {
 
 func getFilesLayout(dirPath string) ([]string, error) {
 	var filesPath []string
-	files, err := ioutil.ReadDir(dirPath)
+	files, err := os.ReadDir(dirPath)
 	if err != nil {
 		return nil, err
 	}
